define(
//begin v1.x content
({
	"descTemplate": "${2} - ${3} z ${1} ${0}",
	"firstTip": "Prvá strana",
	"lastTip": "Posledná strana",
	"nextTip": "Ďalšia strana",
	"prevTip": "Predošlá strana",
	"itemTitle": "položiek",
	"singularItemTitle": "položka",
	"pageStepLabelTemplate": "Strana ${0}",
	"pageSizeLabelTemplate": "${0} položiek na strane",
	"allItemsLabelTemplate": "Všetky položky",
	"gotoButtonTitle": "Prejsť na špecifickú stranu",
	"dialogTitle": "Prejsť na stranu",
	"dialogIndication": "Zadajte číslo strany",
	"pageCountIndication": " (${0} strán)",
	"dialogConfirm": "Prejsť",
	"dialogCancel": "Zrušiť",
	"all": "všetko"
})
//end v1.x content
);
